@@ -20,7 +20,7 @@
 
 namespace
 {
-const char* s_defaultFileExcludeFilters[] = {
+const char* const s_defaultFileExcludeFilters[] = {
     // tmp files
     "*~",
     "*.part",
@@ -64,19 +64,38 @@ const char* s_defaultFileExcludeFilters[] = {
     "*.orig",
     ".histfile.*",
     ".xsession-errors*",
+    "*.map",
+    "*.so",
+    "*.a",
+    "*.db",
+    "*.qrc",
+    "*.ini",
+    "*.init",
 
-    // Compiled files
+    // Bytecode files
     "*.class", // Java
     "*.pyc",   // Python
+    "*.pyo",   // More Python
     "*.elc",   // Emacs Lisp
+    "*.qmlc",  // QML
+    "*.jsc",   // Javascript
 
+    // files known in bioinformatics containing huge amount of unindexable data
+    "*.fastq",
+    "*.fq",
+    "*.gb",
+    "*.fasta",
+    "*.fna",
+    "*.gbff",
+    "*.faa",
+    "*.fna",
     // end of list
-    0
+    nullptr
 };
 
-const int s_defaultFileExcludeFiltersVersion = 2;
+const int s_defaultFileExcludeFiltersVersion = 4;
 
-const char* s_defaultFolderExcludeFilters[] = {
+const char* const s_defaultFolderExcludeFilters[] = {
     "po",
 
     // VCS
@@ -95,18 +114,25 @@ const char* s_defaultFolderExcludeFilters[] = {
     ".obj",
     ".pch",
     ".uic",
+    ".npm",
+    ".yarn",
+    ".yarn-cache",
+    "__pycache__",
+    "node_modules",
+    "node_packages",
+    "nbproject",
 
     //misc
     "core-dumps",
     "lost+found",
 
     // end of list
-    0
+    nullptr
 };
 
-const int s_defaultFolderExcludeFiltersVersion = 1;
+const int s_defaultFolderExcludeFiltersVersion = 2;
 
-const char* s_sourceCodeMimeTypes[] = {
+const char* const s_sourceCodeMimeTypes[] = {
     "text/css",
     "text/x-c++src",
     "text/x-c++hdr",
@@ -119,25 +145,45 @@ const char* s_sourceCodeMimeTypes[] = {
     "text/x-ruby",
     "text/x-scheme",
     "text/x-pascal",
+    "text/x-fortran",
+    "text/x-erlang",
+    "text/x-cmake",
+    "text/x-lua",
     "text/x-yacc",
     "text/x-sed",
     "text/x-haskell",
+    "text/x-copying", // COPYING files
+    "text/x-readme", // README files
+    "text/x-qml",
     "text/asp",
+    "text/jsx",
+    "text/csx",
+    "text/vnd.trolltech.linguist",
     "application/x-awk",
     "application/x-cgi",
     "application/x-csh",
+    "application/x-ipynb+json",
     "application/x-java",
     "application/x-javascript",
     "application/x-perl",
     "application/x-php",
     "application/x-python",
     "application/x-sh",
-    "application/x-tex",
+    "application/xml",
+    "application/javascript",
+    "application/json",
+    "application/geo+json",
+    "application/json-patch+json",
+    "application/ld+json",
+    "application/x-ipynb+json", // Jupyter notebooks
+
+    // Not really source code, but inherited from text/plain
+    "application/pgp-encrypted", // pgp encrypted, with or without ASCII Armor
 
     // end of list
-    0
+    nullptr
 };
-const int s_sourceCodeMimeTypesVersion = 1;
+const int s_sourceCodeMimeTypesVersion = 3;
 }
 
 
@@ -159,7 +205,7 @@ int Baloo::defaultExcludeFilterListVersion()
 QStringList Baloo::sourceCodeMimeTypes()
 {
     QStringList l;
-    for (int i = 0; s_sourceCodeMimeTypes[i]; i++)
+    for (int i = 0; s_sourceCodeMimeTypes[i]; ++i)
         l << QLatin1String(s_sourceCodeMimeTypes[i]);
 
     return l;
