@@ -106,7 +106,7 @@ bool UnIndexedFileIterator::shouldIndex(const QString& filePath, const QString&
     // A folders mtime is updated when a new file is added / removed / renamed
     // we don't really need to reindex a folder when that happens
     // In fact, we never need to reindex a folder
-    if (timeInfo.mTime && mimetype == QLatin1String("inode/directory")) {
+    if (timeInfo.mTime && fileInfo.isDir()) {
         return false;
     }
 
@@ -114,11 +114,7 @@ bool UnIndexedFileIterator::shouldIndex(const QString& filePath, const QString&
         m_mTimeChanged = true;
     }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5,10,0)
     auto fileMTime = fileInfo.metadataChangeTime().toTime_t();
-#else
-    auto fileMTime = fileInfo.created().toTime_t();
-#endif
     if (timeInfo.cTime != fileMTime) {
         m_cTimeChanged = true;
     }
